@@ -141,6 +141,8 @@ my %skip;
 
 my %skip_versions = (
 	   # 'some/sample/file.pm' => [ '1.23', '1.24' ],
+       # version was bumped prior a release to CPAN and released in v5.37.1 - can be removed once v5.37.2 is released
+       'cpan/experimental/lib/experimental.pm' => [ '0.028' ],
 	  );
 
 my $skip_dirs = qr|^t/lib|;
