@@ -207,7 +207,7 @@ $define|true|[yY]*)
 	0.*|1.*|2.0*|2.1*)   cat <<EOM >&4
 I did not know that FreeBSD $osvers supports POSIX threads.
 
-Feel free to tell perlbug@perl.org otherwise.
+Feel free to report that at https://github.com/Perl/perl5/issues otherwise.
 EOM
 	      exit 1
 	      ;;
@@ -324,16 +324,18 @@ d_printf_format_null='undef'
 #1200004 and up
 #1100502 >= version < 1200000
 #1003507 >= version < 1100000
+# Experiments have shown that this doesn't fully work.  The first kernel we know it works is 1200056
 
 FREEBSD_KERNEL_VERSION=`uname -U`
-if  [ $FREEBSD_KERNEL_VERSION -lt 1003507 ] || \
-    [ $FREEBSD_KERNEL_VERSION -ge 1100000 ] && [ $FREEBSD_KERNEL_VERSION -lt 1100502 ] || \
-    [ $FREEBSD_KERNEL_VERSION -ge 1200000 ] && [ $FREEBSD_KERNEL_VERSION -lt 1200004 ]
+#if  [ $FREEBSD_KERNEL_VERSION -lt 1003507 ] || \
+#    [ $FREEBSD_KERNEL_VERSION -ge 1100000 ] && [ $FREEBSD_KERNEL_VERSION -lt 1100502 ] || \
+#    [ $FREEBSD_KERNEL_VERSION -ge 1200000 ] && [ $FREEBSD_KERNEL_VERSION -lt 1200004 ]
+if  [ $FREEBSD_KERNEL_VERSION -lt 1200056 ]
 then
     d_uselocale='undef'
 fi
 
-# https://rt.perl.org/Ticket/Display.html?id=131337
+# https://github.com/Perl/perl5/issues/15984
 # Reported in 11.0-CURRENT with g++-4.8.5:
 # If using g++, the Configure scan for dlopen() fails.
 # Easier for now to just to forcibly set it.
@@ -343,3 +345,25 @@ case "$cc" in
   ;;
 esac
 
+case `uname -p` in
+arm|mips)
+  ;;
+*)
+  test "$optimize" || optimize='-O2'
+  ;;
+esac
+
+# don't modify a supplied -Darchname
+case "$archname" in
+'')
+  cat > UU/archname.cbu <<'EOCBU'
+unamem=`uname -m`
+case "$archname" in
+"$unamem"-*)
+  arch=`uname -p`
+  archname=`echo "$archname" | sed -e "s/^$unamem-/$arch-/"`
+  ;;
+esac
+EOCBU
+  ;;
+esac
