@@ -23,11 +23,6 @@
 #  define PERL_FILE_IS_ABSOLUTE(f) \
         (*(f) == '/' || *(f) == '\\'		/* UNC/rooted path */	\
          || ((f)[0] && (f)[1] == ':'))		/* drive name */
-#elif defined(NETWARE)
-#  define PERL_FILE_IS_ABSOLUTE(f) \
-        (((f)[0] && (f)[1] == ':')		/* drive name */	\
-         || ((f)[0] == '\\' && (f)[1] == '\\')	/* UNC path */	\
-         ||	((f)[3] == ':'))				/* volume name, currently only sys */
 #elif defined(DOSISH)
 #  define PERL_FILE_IS_ABSOLUTE(f) \
         (*(f) == '/'							\
@@ -252,7 +247,9 @@ returning NULL if not found.  The terminating NUL bytes are not compared.
 
 #ifdef HAS_MEMMEM
 #   define ninstr(big, bigend, little, lend)                                \
-            ((char *) memmem((big), (bigend) - (big),                       \
+            (__ASSERT_(bigend >= big)                                       \
+             __ASSERT_(lend >= little)                                      \
+             (char *) memmem((big), (bigend) - (big),                       \
                              (little), (lend) - (little)))
 #else
 #   define ninstr(a,b,c,d) Perl_ninstr(a,b,c,d)
